using Infrastructure;
using Infrastructure.Attribute;
using Infrastructure.Enums;
using Infrastructure.Model;
using Mapster;
using Microsoft.AspNetCore.Mvc;
using ZR.Model.Dto;
using ZR.Model.Models;
using ZR.Service.Business.IBusinessService;
using ZR.Admin.WebApi.Extensions;
using ZR.Admin.WebApi.Filters;
using ZR.Common;
using ZR.Service.Business.IBusinessService.OutStore;
using ZR.Model.Dto.OutStore;

namespace ZR.Admin.WebApi.Controllers.OutStore
{
    /// <summary>
    /// Controller
    /// 
    /// @tableName sap_out_task_record
    /// @author admin
    /// @date 2023-05-10
    /// </summary>
    [Verify]
    [Route("SapInterface")]
    public class SapOutTaskRecordController : BaseController
    {
        /// <summary>
        /// 接口
        /// </summary>
        private readonly ISapOutTaskRecordService _SapOutTaskRecordService;

        public SapOutTaskRecordController(ISapOutTaskRecordService SapOutTaskRecordService)
        {
            _SapOutTaskRecordService = SapOutTaskRecordService;
        }

        /// <summary>
        /// 查询列表
        /// </summary>
        /// <param name="parm"></param>
        /// <returns></returns>
        [HttpGet("QuerySapOutTaskRecord")]
        [ActionPermissionFilter(Permission = "business:sapouttaskrecord:list")]
        public IActionResult QuerySapOutTaskRecord([FromQuery] SapOutTaskRecordQueryDto parm)
        {
            var response = _SapOutTaskRecordService.GetList(parm);
            return SUCCESS(response);
        }

        /// <summary>
        /// 查询未出库完成的出库任务单号数据
        /// </summary>
        /// <param name="parm">出库任务单查询Dto实体类 -- 无分页参数</param>
        /// <returns></returns>
        [HttpPost("QuerySapOutTaskList")]
        [ActionPermissionFilter(Permission = "business:sapdeliverrecord:QuerySapOutTaskList")]
        public IActionResult QuerySapOutTaskList([FromBody] SapOutTaskQueryNoPageDto parm)
        {
            var response = _SapOutTaskRecordService.GetSapOutTaskList(parm);
            return SUCCESS(response);
        }

        /// <summary>
        /// 根据出库任务单号获取出库任务单明细数据
        /// </summary>
        /// <param name="outTaskNo">出库任务单号</param>
        /// <returns></returns>
        [HttpPost("QuerySapOutTaskRecordList")]
        [ActionPermissionFilter(Permission = "business:sapdeliverrecord:QuerySapOutTaskRecordList")]
        public IActionResult QuerySapOutTaskRecordList(string outTaskNo)
        {
            var response = _SapOutTaskRecordService.GetSapOutTaskRecordList(outTaskNo);
            return SUCCESS(response);
        }

        /// <summary>
        /// 查询详情
        /// </summary>
        /// <param name="Id"></param>
        /// <returns></returns>
        [HttpGet("GetSapOutTaskRecord")]
        [ActionPermissionFilter(Permission = "business:sapouttaskrecord:query")]
        public IActionResult GetSapOutTaskRecord(int Id)
        {
            var response = _SapOutTaskRecordService.GetFirst(x => x.Id == Id);

            return SUCCESS(response);
        }

        /// <summary>
        /// 添加
        /// </summary>
        /// <returns></returns>
        [HttpPost("AddSapOutTaskRecord")]
        [ActionPermissionFilter(Permission = "business:sapouttaskrecord:add")]
        [Log(Title = "", BusinessType = BusinessType.INSERT)]
        public IActionResult AddSapOutTaskRecord([FromBody] SapOutTaskRecordDto parm)
        {
            if (parm == null)
            {
                throw new CustomException("请求参数错误");
            }
            var modal = parm.Adapt<SapOutTaskRecord>().ToCreate(HttpContext);

            var response = _SapOutTaskRecordService.AddSapOutTaskRecord(modal);

            return ToResponse(response);
        }

        /// <summary>
        /// 更新
        /// </summary>
        /// <returns></returns>
        [HttpPut("UpdateSapOutTaskRecord")]
        [ActionPermissionFilter(Permission = "business:sapouttaskrecord:edit")]
        [Log(Title = "", BusinessType = BusinessType.UPDATE)]
        public IActionResult UpdateSapOutTaskRecord([FromBody] SapOutTaskRecordDto parm)
        {
            if (parm == null)
            {
                throw new CustomException("请求实体不能为空");
            }
            var modal = parm.Adapt<SapOutTaskRecord>().ToUpdate(HttpContext);

            var response = _SapOutTaskRecordService.UpdateSapOutTaskRecord(modal);

            return ToResponse(response);
        }

        /// <summary>
        /// 删除
        /// </summary>
        /// <returns></returns>
        [HttpDelete("DeleteSapOutTaskRecord")]
        [ActionPermissionFilter(Permission = "business:sapouttaskrecord:delete")]
        [Log(Title = "", BusinessType = BusinessType.DELETE)]
        public IActionResult DeleteSapOutTaskRecord(string ids)
        {
            int[] idsArr = Tools.SpitIntArrary(ids);
            if (idsArr.Length <= 0) { return ToResponse(ApiResult.Error($"删除失败Id 不能为空")); }

            var response = _SapOutTaskRecordService.Delete(idsArr);

            return ToResponse(response);
        }
    }
}